#include <algorithm>
#include <cstdlib>
#include <ctime>
#include <iostream>
#include <tuple>
#include <vector>

int distancia(int x1, int y1, int x2, int y2)
{
   int dx = x1 - x2;
   int dy = y1 - y2;

   return dx * dx + dy * dy;
}

struct distancia_con {
   bool operator()(std::tuple<int, int> p1, std::tuple<int, int> p2) const
   {
      auto d1 = distancia(std::get<0>(p1), std::get<1>(p1), x, y);
      auto d2 = distancia(std::get<0>(p2), std::get<1>(p2), x, y);

      return d1 < d2 || (d1 == d2 && p1 < p2);
   }

   int x;
   int y;
};

int mas_cercano(const std::vector<std::tuple<int, int>>& centros, int x, int y)
{
   return std::min_element(centros.begin( ), centros.end( ), distancia_con{x, y}) - centros.begin( );
}

std::tuple<int, int> calcula_centro(const std::vector<std::tuple<int, int>>& puntos, const std::vector<int>& grupo)
{
   int x = 0;
   int y = 0;

   for (int i = 0; i < grupo.size( ); ++i) {
      x += std::get<0>(puntos[grupo[i]]);
      y += std::get<1>(puntos[grupo[i]]);
   }

   return std::make_tuple(x / grupo.size( ), y / grupo.size( ));
}

int main( )
{
   std::srand(std::time(nullptr));

   int n;
   std::cin >> n;

   char tablero[n][n];
   std::vector<std::tuple<int, int>> puntos;

   for (int i = 0; i < n; ++i) {
      for (int j = 0; j < n; ++j) {
         std::cin >> tablero[i][j];

         if (tablero[i][j] == '*') {
            puntos.push_back(std::make_pair(i, j));
         }
      }
   }

   int k = 15;

   std::random_shuffle(puntos.begin( ), puntos.end( ));
   std::vector<std::tuple<int, int>> centros(puntos.begin( ), puntos.begin( ) + std::min(k, int(puntos.size( ))));

   for (;;) {
      std::vector<int> grupos[k];

      for (int i = 0; i < puntos.size( ); ++i) {
         grupos[mas_cercano(centros, std::get<0>(puntos[i]), std::get<1>(puntos[i]))].push_back(i);
      }

      std::vector<std::tuple<int, int>> nuevos;

      for (int i = 0; i < centros.size( ); ++i) {
         nuevos.push_back(calcula_centro(puntos, grupos[i]));
      }

      if (nuevos == centros) {
         break;
      }

      centros = std::move(nuevos);
   }

   for (int i = 0; i < n; ++i) {
      for (int j = 0; j < n; ++j) {
         if (tablero[i][j] == '*') {
            tablero[i][j] = mas_cercano(centros, i, j) + 'A';
         }
      }
   }

   for (int i = 0; i < n; ++i) {
      for (int j = 0; j < n; ++j) {
         std::cout << tablero[i][j];
      }

      std::cout << '\n';
   }
}
